==> apache-geode-1.14.4-src.tgz: apache-geode-1.14.4-src/geode-gfsh/src/main/java/org/apache/geode/management/internal/cli/domain/StackTracesPerMember.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.management.internal.cli.domain;

import java.io.Serializable;
import java.time.Instant;

public class StackTracesPerMember implements Serializable {

  private static final long serialVersionUID = 1L;
  private final String memberNameOrId;
  private final Instant timestamp;
  private final byte[] stackTraces;

  public StackTracesPerMember(String memberNameOrId, Instant timestamp,
      byte[] stackTraces) {
    this.memberNameOrId = memberNameOrId;
    this.timestamp = timestamp;
    this.stackTraces = stackTraces;
  }

  public String getMemberNameOrId() {
    return this.memberNameOrId;
  }

  public Instant getTimestamp() {
    return this.timestamp;
  }

  public byte[] getStackTraces() {
    return this.stackTraces;
  }
}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-gfsh/src/main/java/org/apache/geode/management/internal/cli/domain/StackTracesPerMember.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.management.internal.cli.domain;

import java.io.Serializable;
import java.time.Instant;

public class StackTracesPerMember implements Serializable {

  private static final long serialVersionUID = 1L;
  private final String memberNameOrId;
  private final Instant timestamp;
  private final byte[] stackTraces;

  public StackTracesPerMember(String memberNameOrId, Instant timestamp,
      byte[] stackTraces) {
    this.memberNameOrId = memberNameOrId;
    this.timestamp = timestamp;
    this.stackTraces = stackTraces;
  }

  public String getMemberNameOrId() {
    return memberNameOrId;
  }

  public Instant getTimestamp() {
    return timestamp;
  }

  public byte[] getStackTraces() {
    return stackTraces;
  }
}
